# Instructions
- Never fail silently. If tests don't pass fix the test. Never skip the tests.
- Never fail silently. If can't parse the query, return an error. Don't fallback to default or whatever. If there is an error. Return Error to the client.
- Don't remove any existing files unless you are explicitly told. 
- Don't remove any existing feature/functionality unless you are explicitly told.
- Always run tests, if tests fail fix the code. If you can't fix the code, or fail to implement the task, it's fine to fail. You can give up.
- For any given task add test cases. Don't try to finish the task without any tests. 

- For function parameters never use one letter parameters. Always be descriptive.
- Try to keep newly added functions less than 100 lines
